@@ -216,10 +216,10 @@ void LegendVisitor::build()
 
 	if ( !empty() ) {
 		if ( use_min_ ) {
-			front()->userText(use_min_text_);
+			front()->userText(use_min_text_, "user");
 		}
 		if ( use_max_ ) {
-			back()->userText(use_max_text_);
+			back()->userText(use_max_text_, "user");
 		}
 	
 		back()->units(units_text_);
@@ -262,7 +262,7 @@ void LegendVisitor::build()
 						if (label == lines_.end()) --label;
 					}
 		}
-
+		(**entry).userText(text, composition_);
 		legend->setFont(font);
 		legend->setText(text);
 		legend->setAngle((orientation_/180.)*3.14);
@@ -412,6 +412,9 @@ void  LegendVisitor::rightTitle()
 
 	titleAngle_ = column ? magics::PI * 0.5 : 0;
 	float factor = column ? 0.25 : 0.15;
+	// Special adjustement for the web ( PDF creation) 
+	//titlePosition_ = Paperoint(maxx+ (newmaxx-maxx)*factor, (maxy - miny)/2);
+	//titleJustification_ = ( column ) ?  MCENTRE : MRIGHT;
 	titlePosition_ = PaperPoint(maxx+ (newmaxx-maxx)*factor, (maxy + 3*miny)/4);
 	titleJustification_ = MLEFT;
 
@@ -781,13 +784,19 @@ void BoxEntry::rowBox(const PaperPoint& point, BasicGraphicsObjectContainer& leg
 		from->setVerticalAlign(MBOTTOM);
 		from->setAngle(angle_);
 		legend.push_back(from);
-		if ( userText_.empty()  || last_) {
+		if ( automatic_ ) {
 			ostringstream bottom;
 			bottom << MagicsFormat(format_, from_);
 			from->addText(bottom.str(), font_);
 		}
-		else
-			from->addText(userText_, font_);
+		else 
+			if ( !last_ ) 
+				from->addText(userText_, font_);
+			else {
+				ostringstream bottom;
+				bottom << MagicsFormat(format_, from_);
+				from->addText(bottom.str(), font_);
+			}
 	}
 	if ( last_ ) {		
 		Text* to = new Text();
@@ -795,24 +804,38 @@ void BoxEntry::rowBox(const PaperPoint& point, BasicGraphicsObjectContainer& leg
 		to->setVerticalAlign(MBOTTOM);
 		to->push_back(PaperPoint(x+width, y - height- 0.25));
 		legend.push_back(to);
-		if ( userText_.empty()  ) {
+		if ( automatic_  ) {
 			ostringstream top, bottom;
 			top << MagicsFormat(format_, to_);
 			to->addText(top.str(), font_);
 		}
-		else
+		else 
 			to->addText(userText_, font_);
 	}
 
 
+	Polyline* top = new Polyline();
+	top->push_back(PaperPoint(x-width, y+(height*2)));
+	top->push_back(PaperPoint(x+width, y+(height*2)));
+	top->setColour(borderColour_);
+	top->setThickness(2);
+	
+	Polyline* bottom = new Polyline();
+	bottom->push_back(PaperPoint(x-width, y-height));
+	bottom->push_back(PaperPoint(x+width, y-height));
+	bottom->setColour(borderColour_);
+	bottom->setThickness(2);
+	
 	box_->push_back(PaperPoint(x-width, y-height));
 	box_->push_back(PaperPoint(x-width, y+height+height));
 	box_->push_back(PaperPoint(x+width, y+height+height));
 	box_->push_back(PaperPoint(x+width, y-height));
 	box_->push_back(PaperPoint(x-width, y-height));
+	
 	// Small check 
 	Colour colour = ( borderColour_.automatic() ) ? box_->getFillColour() : borderColour_;
 
+
 	if ( box_->getFillColour() == Colour("none") ) {
 		box_->setFilled(false);
 		colour = Colour("black");
@@ -821,6 +844,27 @@ void BoxEntry::rowBox(const PaperPoint& point, BasicGraphicsObjectContainer& leg
 
 
 	legend.push_back(box_);
+	legend.push_back(top);
+	legend.push_back(bottom);
+
+	if ( last_ ) {
+		Polyline* right = new Polyline();
+		right->push_back(PaperPoint(x+width, y-height));
+		right->push_back(PaperPoint(x+width, y+(height*2)));
+		right->setColour(borderColour_);
+		right->setThickness(2);
+		legend.push_back(right);
+	}
+
+	if ( first_ ) {
+		Polyline* left = new Polyline();
+		left->push_back(PaperPoint(x-width, y-height));
+		left->push_back(PaperPoint(x-width, y+(height*2)));
+		left->setColour(borderColour_);
+		left->setThickness(2);
+		legend.push_back(left);
+	}
+	
 }
 
 void BoxEntry::rowHisto(const PaperPoint& point, BasicGraphicsObjectContainer& legend, const Colour& colour)
@@ -847,7 +891,8 @@ void BoxEntry::rowHisto(const PaperPoint& point, BasicGraphicsObjectContainer& l
 			from->setVerticalAlign(MTOP);
 			from->setAngle(angle_);
 			legend.push_back(from);
-			if ( userText_.empty()  || last_) {
+
+			if ( automatic_ ) {
 				ostringstream bottom;
 				bottom << MagicsFormat(format_, from_);
 				from->addText(bottom.str(), font_);
@@ -867,7 +912,7 @@ void BoxEntry::rowHisto(const PaperPoint& point, BasicGraphicsObjectContainer& l
 			to->setVerticalAlign(MTOP);
 			to->push_back(PaperPoint(x+width, y + 1.3));
 			legend.push_back(to);
-			if ( userText_.empty()  ) {
+			if ( automatic_  ) {
 				ostringstream top, bottom;
 				top << MagicsFormat(format_, to_);
 				to->addText(top.str(), font_);
@@ -896,7 +941,7 @@ void BoxEntry::rowHisto(const PaperPoint& point, BasicGraphicsObjectContainer& l
 		to->setJustification(MRIGHT);
 		to->push_back(PaperPoint(x-width, y - 0.2 ));
 		legend.push_back(to);
-		if ( userText_.empty() && histogram_->max() ) {
+		if ( userText_.empty() && histogram_->max() && automatic_ ) {
 			ostringstream top, bottom;
 			top << MagicsFormat(format_, totalPopulation_);
 			to->addText(top.str(), font_);
@@ -1008,13 +1053,14 @@ void BoxEntry::columnBox(const PaperPoint& point, BasicGraphicsObjectContainer&
 		Text* from = new Text();
 		from->setJustification(MLEFT);
 		from->setVerticalAlign(MHALF);
-		if ( userText_.empty()  || last_) {
+		if ( automatic_ ) {
 			ostringstream bottom;
 			bottom << MagicsFormat(format_, from_);
 			from->addText(bottom.str(), font_);
 		}
-		else
-			from->addText(userText_, font_);
+		else 
+			if ( !last_ ) 
+				from->addText(userText_, font_);
 		PaperPoint pfrom(pt);
 		pfrom.y_ = y - height;
 		from->push_back(pfrom);
@@ -1026,7 +1072,7 @@ void BoxEntry::columnBox(const PaperPoint& point, BasicGraphicsObjectContainer&
 		to->setVerticalAlign(MHALF);
 		to->setJustification(MLEFT);
 		to->setAngle(angle_);
-		if ( userText_.empty()  ) {
+		if ( automatic_  ) {
 			ostringstream top, bottom;
 			top << MagicsFormat(format_, to_);
 			to->addText(top.str(), font_);
@@ -1049,7 +1095,40 @@ void BoxEntry::columnBox(const PaperPoint& point, BasicGraphicsObjectContainer&
 	}
 	box_->setColour(colour);
 	legend.push_back(box_);
+
+	Polyline* left = new Polyline();
+	left->push_back(PaperPoint(x-width, y-(height)));
+	left->push_back(PaperPoint(x-width, y+(height)));
+	left->setColour(borderColour_);
+	left->setThickness(2);
+	
+	Polyline* right = new Polyline();
+	right->push_back(PaperPoint(x+width, y-height));
+	right->push_back(PaperPoint(x+width, y+(height)));
+	right->setColour(borderColour_);
+	right->setThickness(2);
+	
+	legend.push_back(left);
+	legend.push_back(right);
+	
+	if ( last_ ) {
+		Polyline* top = new Polyline();
+		top->push_back(PaperPoint(x-width, y+(height)));
+		top->push_back(PaperPoint(x+width, y+(height)));
+		top->setColour(borderColour_);
+		top->setThickness(2);
+		legend.push_back(top);
+	}
+	if ( first_ ) {
+		Polyline* bottom = new Polyline();
+		bottom->push_back(PaperPoint(x-width, y-height));
+		bottom->push_back(PaperPoint(x+width, y-height));
+		bottom->setColour(borderColour_);
+		bottom->setThickness(2);
+		legend.push_back(bottom);
+	}
 }
+
 void BoxEntry::columnHisto(const PaperPoint& point, BasicGraphicsObjectContainer& legend, const Colour& colour)
 {
 
