@@ -33,6 +33,8 @@
 #include "HistoVisitor.h"
 
 #include "AnimationRules.h"
+#include <MagConfig.h>
+
 
 using namespace magics;
 
@@ -547,11 +549,22 @@ protected:
 	double parent_;
 };
 
+
 void FortranViewNode::getReady()
 {
 	ASSERT (parent_);
-	
-	viewTransformation_ = FortranViewNodeAttributes::transformation_.get();
+
+	if ( predefined_ ) {
+			StyleLibrary library("projections");
+			const map<string, string>& area = library.get(predefined_name_);
+			
+			viewTransformation_ = MagTranslator<string, Transformation>()(area.find("subpage_map_projection")->second);
+			viewTransformation_->set(area);
+			viewTransformation_->init();
+	}
+	else {
+		viewTransformation_ = FortranViewNodeAttributes::transformation_.get();
+	}
 	viewTransformation_->setDefinition(json_);
 
 //	MagLog::dev()<< *viewTransformation_ << endl;
