@@ -71,12 +71,10 @@ PaperPoint GeoRectangularProjection::operator()(const UserPoint& point)  const
 		return  PaperPoint(point.x(), point.y(), point.value(), point.missing(), point.border(), 0, point.name());
 
 	}
-	if ( point.y() < -85.)
-		cout << point.y() << endl;
+	
 	TeCoord2D geo = TeCoord2D(point.x()*TeCDR, point.y()*TeCDR);
 	TeCoord2D xy = projection_->LL2PC(geo);
-	if ( point.y() < -85.)
-		cout << xy.y() << endl;
+	
 	return PaperPoint(xy.x(), xy.y(), point.value(), point.missing(), point.border(), 0, point.name());
 }
 
@@ -694,3 +692,11 @@ double MercatorProjection::patchDistance(double) const
 {
 	return 1000000;
 }
+
+double GeoRectangularProjection::ratio() const
+{
+	// return domain/fulldomain! 
+
+	return (( max_longitude_ - min_longitude_ ) * ( max_latitude_ - min_latitude_) ) / (360*180);
+
+}
