@@ -1,22 +1,12 @@
-
-
-/******************************** LICENSE ********************************
-
- Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
-
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at 
-
-    http://www.apache.org/licenses/LICENSE-2.0
-
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
- 
- ******************************** LICENSE ********************************/
+/*
+ * (C) Copyright 1996-2016 ECMWF.
+ * 
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+ * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * granted to it by virtue of its status as an intergovernmental organisation nor
+ * does it submit to any jurisdiction.
+ */
 
 /*! \file Matrix.h
     \brief Implementation of the Template class Matrix.
@@ -67,127 +57,7 @@ pair<int, bool> InfoIndex::index(double pos) const
 
 void ProjectedMatrix::build()
 {
-	/*
-	vector< std::pair<int, int>  > coords(4);
-	for (int r = 0; r < rows_; r++)
-		for (int c = 0; c < columns_; c++)
-			push_back(missing_);
 	
-	coords[0] = std::make_pair(0,0);
-	coords[1] = std::make_pair(0,1);
-	coords[2] = std::make_pair(1,1);
-	coords[3] = std::make_pair(1,0);
-	
-	Timer  t("GridHelper::build", "GridHelper");
-	for ( int row = 0 ; row < origRows_-1; row++)
-		for ( int column = 0 ; column < origColumns_-1; column++)
-		{
-			double xmin = origColumns_;
-			double xmax = 0;
-			double ymin = rows_;
-			double ymax = 0;
-			
-			vector<double> x, y, v;
-			vector<double> xs, ys, vs;
-			vector<Point> points;
-			bool stop = true;
-			
-			for (vector< std::pair<int, int>  >::iterator p = coords.begin(); p != coords.end(); ++p) {
-				int r = row+ p->first;
-				int c = column+ p->second;
-				double rr = rowsArray_[index(r, c)];
-				double cc = columnsArray_[index(r, c)];
-				MagLog::debug() << rr << " ? " << miny_ -  stepy_ << " " <<  maxy_ + stepy_ << endl;
-				MagLog::debug() << cc << " ? " << minx_ -  stepx_ << " " <<  maxx_ + stepx_ << endl;
-				if ( rr >= miny_ -  stepy_ && rr <= maxy_ + stepy_)
-					stop = false;
-
-				if ( cc >= minx_ -  stepx_ && cc <= maxx_ + stepx_ )
-					stop = false;
-				
-			}
-			if ( stop )
-				// Go to next cell...
-
-				continue;
-			for (vector< std::pair<int, int>  >::iterator p = coords.begin(); p != coords.end(); ++p) {
-				
-				int r = row+ p->first;
-				int c = column+ p->second;
-				double  rr = rowsArray_[index(r, c)];
-				double cc = columnsArray_[index(r, c)];
-				
-				
-
-				 x.push_back( (cc - minx_ ) / stepx_ );
-				 y.push_back( (rr - miny_ ) / stepy_);
-
-				 points.push_back(Point(x.back(), y.back()));
-				 v.push_back( values_[index(r, c)]);  						
-			}
-			points.push_back(points.front());
-			xmin = *std::min_element(x.begin(), x.end());
-			xmax = *std::max_element(x.begin(), x.end());
-			ymin = *std::min_element(y.begin(), y.end());
-			ymax = *std::max_element(y.begin(), y.end());
-
-			MagLog::debug() << "x------->" << xmin << " " << xmax << endl;
-			MagLog::debug() << "y------->" << ymin << " " << ymax << endl;
-			int ii = (xmin < 0) ? 0 : xmin;
-
-			while (ii <= xmax && ii < columns_ )
-			{
-				int jj = (ymin < 0) ? 0 : ymin;
-				while ( jj <= ymax && jj < rows_ ) {
-			
-					MagLog::debug() << "ii=" << 	ii << "  jj=" << jj <<  endl;
-					// is the point inside or oiutside .. if inside use it! 
-
-				    int i = 0;
-				    bool done = false;
-					for (vector<Point>::iterator pt = points.begin(); pt != points.end(); ++pt) {
-				    	MagLog::debug() << *pt << endl;
-						if ( *pt == Point(ii, jj) ) {
-							(*this)[(jj*columns_) + ii] = v[i];
-							done = true;
-				    		break;
-				    	}
-						i++;
-				    }
-					if (  !done && SegmentJoiner::pointInPoly(Point(ii, jj),  points) )
-					 {
-						//feed the matrix...
-						vector<double> w;
-						double total = 0.;
-						for (unsigned int i = 0; i < x.size(); i++) {
-							double val = sqrt( ((ii - x[i])*(ii-x[i]))  + ( (jj-y[i])*(jj-y[i]) ) );
-
-														w.push_back(1/ (val) ? (val*val) : 1);
-														if (v[i] != missing_)
-														    total += w[i];
-						}
-						
-						double val = 0.;
-						for (unsigned int i = 0; i < w.size(); i++) {
-							if (v[i] != missing_) 
-								val += (v[i]*w[i]/total);
-							}
-
-				     (*this)[(jj*columns_) + ii] = val;
-				     MagLog::debug() << "[" << ii << ", " << jj << "]=" << val << endl;
-				     MagLog::debug() << "[" << ii <<  "]=" << columnsAxis_[ii] << endl;
-				     MagLog::debug() << "[" << jj <<  "]=" << rowsAxis_[jj] << endl;
-					}else {
-						MagLog::debug() <<  "out[" << ii <<  "]=" << columnsAxis_[ii] << endl;
-				     MagLog::debug() << "out[" << jj <<  "]=" << rowsAxis_[jj] << endl;
-					}
-
-					jj++;
-				}
-				ii++;
-			}
-		}
-		*/
 }
 
 void ProjectedMatrix::getReady()
@@ -236,12 +106,7 @@ ProjectedMatrix::ProjectedMatrix(int rows, int columns): Matrix(rows, columns)
 	       rowsArray_.reserve(rows*columns);  
 	       columnsArray_.reserve(rows*columns);
 }
-RotatedMatrix::RotatedMatrix(int rows, int columns): Matrix(rows, columns)
-{
-	rowsArray_.reserve(rows*columns);
-	columnsArray_.reserve(rows*columns);
-	values_.reserve(rows*columns);
-}
+
 
 
 
@@ -324,7 +189,7 @@ double Matrix::interpolate(double i, double j) const
 
 
 /// @brief The usual PI/180 constant
-static const double DEG_TO_RAD = 0.017453292519943295769236907684886;
+//static const double DEG_TO_RAD = 0.017453292519943295769236907684886;
 /// @brief Earth's quatratic mean radius for WGS-84
 static const double EARTH_RADIUS_IN_METERS = 6372797.560856;
 
@@ -368,6 +233,7 @@ pair<double, double> Matrix::nearest_value(double row, double column,double &row
 	rowOut = missing();
 	colOut = missing();
 
+
 	vector<pair<double, map<double, pair<double, double> >::const_iterator> > points;
 	row_index = index_.find(row);
 
@@ -431,30 +297,15 @@ pair<double, double> Matrix::nearest_value(double row, double column,double &row
 }
 
 
-void xx(double v)
-{
-	double offset;
-	offset = fmod(v, 360.);
-	int a = v/360;
-	cout << "-------" << endl;
-	cout << v << "--->" << offset  << "--->" << a <<  endl;
 
-	if ( offset < 0 )
-		a--;
-
-	double nv = v - (a*360);
-
-	cout << nv << "--->" << (a*360) << " " <<  nv + (a*360) << endl;
-
-
-
-}
 
 
 int Matrix::nearest_index(double row, double column,double &rowOut, double &colOut) const
 {
 	double col, offset;
 
+
+	
 	int factor = (column-minX())/360.;
 
 	if ( column-minX() < 0)
@@ -463,12 +314,23 @@ int Matrix::nearest_index(double row, double column,double &rowOut, double &colO
 	offset = (factor*360);
 
 	col = column - offset;
+	rowOut = missing();
+	colOut = missing();
+
+	if ( col < left() || col > right() ) {
+
+		
+		return -1;
+	} 
+	if ( row < bottom() || row > top() ) {
+		
+		return -1;
+	} 
 	map<double, int >::const_iterator  row_index;
 	pair<int, bool> column_index;
 	vector<pair<double, pair<double, int> > > points;
 
-	rowOut = missing();
-	colOut = missing();
+	
 
 
 	row_index = yIndex_.find(row);
@@ -607,10 +469,13 @@ double Matrix::operator()(int row, int column) const
 GeoBoxMatrixHandler::GeoBoxMatrixHandler(const AbstractMatrix& matrix, const Transformation& transformation):
 	  TransformMatrixHandler(matrix), transformation_(transformation), original_(0)
 {
+
 	map<double, int> lats;
 	map<double, int> lons;
+	
 	double lon, lat;
 	double minlon, minlat, maxlon, maxlat;
+	
 
 	transformation.boundingBox(minlon, minlat, maxlon, maxlat);
 
@@ -644,12 +509,10 @@ GeoBoxMatrixHandler::GeoBoxMatrixHandler(const AbstractMatrix& matrix, const Tra
 	for (int i = 0; i < columns; i++)
 	{
 		lon = matrix_.regular_column(i);
-
-		if ( minlon <= lon && lon <= maxlon)
+		if ( minlon <= lon && lon <= maxlon) 
 			lons[lon] = i;
 
 		double ml = lon - 360;
-
 		while ( ml >= minlon && ml <= maxlon ) {  lons[ml] = i; ml -= 360; }
 		ml = lon + 360;
 		while (  ml >= minlon && ml <= maxlon ) {  lons[ml] = i; ml += 360; }
@@ -671,7 +534,9 @@ GeoBoxMatrixHandler::GeoBoxMatrixHandler(const AbstractMatrix& matrix, const Tra
 	for (int i = 0; i < rows; i++) {
 
 		lat = matrix_.regular_row(i);
-		if ( minlat <= lat && lat <= maxlat) lats[lat] = i;
+		if ( minlat <= lat && lat <= maxlat) 
+			lats[lat] = i;
+		
 
 	}
 	i = 0;
@@ -682,12 +547,199 @@ GeoBoxMatrixHandler::GeoBoxMatrixHandler(const AbstractMatrix& matrix, const Tra
 		i++;
 	}
 
+	
+}
+
 
-}
-MatrixHandler* RotatedMatrix::getReady(const Transformation&) const
-{
-	return new MatrixHandler(*this);
-}
 MatrixHandler* Matrix::getReady(const Transformation& transformation)  const{
 	return transformation.prepareData(*this);
 }
+
+MatrixHandler* Proj4Matrix::getReady(const Transformation&) const
+{
+	return new Proj4MatrixHandler(*this, proj4_);
+}
+
+MatrixHandler* RotatedMatrix::getReady(const Transformation&) const
+{
+	return new RotatedMatrixHandler(*this, southPoleLat_, southPoleLon_);
+}
+
+
+
+Proj4MatrixHandler::Proj4MatrixHandler(const AbstractMatrix& matrix, const string& proj4) : MatrixHandler(matrix) 
+{
+	proj4_ = pj_init_plus(proj4.c_str());
+	latlon_ = pj_init_plus("+proj=longlat +ellps=WGS84 +datum=WGS84");
+	internal_ = false;
+}
+
+RotatedMatrixHandler::RotatedMatrixHandler(const AbstractMatrix& matrix,  double lat, double lon) : 
+	MatrixHandler(matrix), southPoleLat_(lat), southPoleLon_(lon) 
+{
+	internal_ = false;
+}
+
+
+       
+double Proj4MatrixHandler::interpolate(double  row, double  column) const 
+{
+	if (internal_)
+		return MatrixHandler::interpolate(row, column);
+	double x = column * DEG_TO_RAD;
+	double y = row * DEG_TO_RAD;
+
+    int error = pj_transform(latlon_, proj4_, 1, 1, &x, &y, NULL);
+    if ( error )
+    	return missing();
+
+    return MatrixHandler::interpolate(y, x);
+}
+
+double Proj4MatrixHandler::nearest(double  row, double  column) const
+{
+	if (internal_)
+		return MatrixHandler::nearest(row, column);
+	double x = column * DEG_TO_RAD;
+	double y = row * DEG_TO_RAD;
+
+    int error = pj_transform(latlon_, proj4_, 1, 1, &x, &y, NULL);
+    if ( error )
+    	return missing();
+
+    return MatrixHandler::nearest(y, x);
+}
+
+double RotatedMatrixHandler::interpolate(double  row, double  column) const 
+{
+	if (internal_)
+		return MatrixHandler::interpolate(row, column);
+	
+	pair<double, double> point = rotate(row, column);
+    return MatrixHandler::interpolate(point.first, point.second);
+}
+
+double RotatedMatrixHandler::nearest(double  row, double  column) const
+{
+	if (internal_)
+		return MatrixHandler::nearest(row, column);
+	pair<double, double> point = rotate(row, column);
+    return MatrixHandler::nearest(point.first, point.second);
+}
+
+RotatedMatrix::RotatedMatrix(int rows, int columns, double lat, double lon) : 
+Matrix(rows, columns), southPoleLat_(lat), southPoleLon_(lon) 
+{
+    helper_ = new RotatedMatrixHandler(*this, southPoleLat_, southPoleLon_);
+}
+int RotatedMatrix::nearest_index(double lat, double lon,double &nlat, double &nlon) const
+{
+	
+	pair<double, double> point = helper_->rotate(lat, lon);
+	int index = Matrix::nearest_index(point.first, point.second, nlat, nlon);
+	if ( index != -1 ) {
+		point = helper_->unrotate(nlat, nlon);
+		nlat = point.first;
+		nlon = point.second;
+	}
+	return index;
+}
+
+double RotatedMatrixHandler::column(int i , int j) const
+{
+	double column = MatrixHandler::column(i, j);
+	double row = MatrixHandler::row(i, j);
+
+	pair<double, double> point = unrotate(row, column);
+    return point.second;
+}
+
+double RotatedMatrixHandler::row(int i, int j) const
+{
+	double column = MatrixHandler::column(i, j);
+	double row = MatrixHandler::row(i, j);
+
+	pair<double, double> point = unrotate(row, column);
+    return point.first;
+   
+}
+
+double Proj4MatrixHandler::column(int i , int j) const
+{
+	double column = MatrixHandler::column(i, j);
+	double row = MatrixHandler::row(i, j);
+
+	int error = pj_transform(proj4_, latlon_, 1, 1, &column, &row, NULL);
+    if ( error )
+    	return missing();
+    return column * RAD_TO_DEG;
+	
+
+}
+
+double Proj4MatrixHandler::row(int i, int j) const
+{
+	double column = MatrixHandler::column(i, j);
+	double row = MatrixHandler::row(i, j);
+
+	int error = pj_transform(proj4_, latlon_, 1, 1, &column, &row, NULL);
+    if ( error )
+    	return missing();
+    return row * RAD_TO_DEG;
+}
+    
+pair<double, double> RotatedMatrixHandler::rotate(double lat_y,  double lon_x) const 
+{
+    const double cToRadians = M_PI / 180.0;
+    double ZRADI = 1. / cToRadians;
+    double ZSYCEN = sin(cToRadians * (southPoleLat_ + 90.));
+    double ZCYCEN = cos(cToRadians * (southPoleLat_ + 90.));
+
+    double ZXMXC = cToRadians * (lon_x - southPoleLon_);
+    double ZSXMXC = sin(ZXMXC);
+    double ZCXMXC = cos(ZXMXC);
+    double ZSYREG = sin(cToRadians * lat_y);
+    double ZCYREG = cos(cToRadians * lat_y);
+    double ZSYROT = ZCYCEN * ZSYREG - ZSYCEN * ZCYREG * ZCXMXC;
+    ZSYROT = MAX(MIN(ZSYROT, +1.0), -1.0);
+
+    double PYROT = asin(ZSYROT) * ZRADI;
+
+    double ZCYROT = cos(PYROT * cToRadians);
+    double ZCXROT = (ZCYCEN * ZCYREG * ZCXMXC + ZSYCEN * ZSYREG) / ZCYROT;
+    ZCXROT = MAX(MIN(ZCXROT, +1.0), -1.0);
+    double ZSXROT = ZCYREG * ZSXMXC / ZCYROT;
+
+    double PXROT = acos(ZCXROT) * ZRADI;
+
+    if (ZSXROT < 0.0)
+        PXROT = -PXROT;
+
+    return std::make_pair(PYROT, PXROT);
+}
+
+pair<double, double> RotatedMatrixHandler::unrotate(double lat_y, double lon_x) const 
+{
+    const double cToRadians = M_PI / 180.0;
+    double ZRADI = 1. / cToRadians;
+    double ZSYCEN = sin(cToRadians * (southPoleLat_ + 90.));
+    double ZCYCEN = cos(cToRadians * (southPoleLat_ + 90.));
+    double ZSXROT = sin(cToRadians * lon_x);
+    double ZCXROT = cos(cToRadians * lon_x);
+    double ZSYROT = sin(cToRadians * lat_y);
+    double ZCYROT = cos(cToRadians * lat_y);
+    double ZSYREG = ZCYCEN * ZSYROT + ZSYCEN * ZCYROT * ZCXROT;
+    ZSYREG = MAX(MIN(ZSYREG, +1.0), -1.0);
+    double PYREG = asin(ZSYREG) * ZRADI;
+    double ZCYREG = cos(PYREG * cToRadians);
+    double ZCXMXC = (ZCYCEN * ZCYROT * ZCXROT - ZSYCEN * ZSYROT) / ZCYREG;
+    ZCXMXC = MAX(MIN(ZCXMXC, +1.0), -1.0);
+    double ZSXMXC = ZCYROT * ZSXROT / ZCYREG;
+    double ZXMXC = acos(ZCXMXC) * ZRADI;
+    if (ZSXMXC < 0.0)
+        ZXMXC = -ZXMXC;
+    double PXREG = ZXMXC + southPoleLon_;
+    return std::make_pair(PYREG, PXREG);
+}
+
+   
