@@ -39,7 +39,7 @@ class MatrixHandler : public AbstractMatrix, public AbstractPoints
 public : 
     MatrixHandler(const AbstractMatrix& matrix) : AbstractMatrix(),
         AbstractPoints(),
-        matrix_(matrix), min_(INT_MAX), max_(-INT_MAX)  {}
+        matrix_(matrix), min_(INT_MAX), max_(-INT_MAX) {}
     MatrixHandler(const MatrixHandler& matrix) :
         AbstractMatrix(),
         AbstractPoints(),
@@ -51,7 +51,7 @@ public :
     virtual int rowIndex(double r) const     { return matrix_.rowIndex(r); } 
     virtual int columnIndex(double c) const  { return matrix_.columnIndex(c); }  
     virtual bool  akimaEnable() const  { return matrix_.akimaEnable(); }
-    
+    virtual bool  delegate() const  { return matrix_.delegate(); }
     
     virtual void boundRow(double r, 
     	double& row1, int& index1, double& row2, int& index2) const 
@@ -145,6 +145,7 @@ public :
 	
     virtual double interpolate(double  i, double  j) const 
     {
+
     	if ( columns() == 0  || rows() == 0)
     		return matrix_.missing();
 
@@ -167,10 +168,10 @@ public :
     		boundRow(i, v1, i1, v2, i2);
     		
     		if (i1 == -1) return missing(); 
-    		
+    		internal_ = true;
     	    double a = (*this).interpolate(v1, j);
             double b = (*this).interpolate(v2, j);
-          
+            internal_ = false;
             if ( same(a, missing()) || same(b, missing()) ) return missing();
             
             double da = (v2-i)/(v2-v1);
@@ -212,7 +213,7 @@ public :
     virtual double  width() const { return matrix_.width(); } 
     virtual double  height() const { return matrix_.height(); } 
     
-    virtual const AbstractMatrix& original() const { return matrix_.original(); }
+    virtual const AbstractMatrix& original() const { return delegate() ?  matrix_ : matrix_.original(); }
     virtual int firstRow() const 	{ return matrix_.firstRow(); }
     virtual int nextRow(int i, int f) const   { return matrix_.nextRow(i, f); }
     virtual int firstColumn() const { return matrix_.firstColumn(); }
@@ -338,6 +339,7 @@ protected:
     mutable VectorOfPointers<vector<UserPoint*> >::const_iterator current_;
     mutable double min_;
     mutable double max_;
+    mutable bool internal_;
   
 };
 
@@ -486,9 +488,87 @@ protected :
    bool columnrevert_;
 };
 
+class DelegateMatrixHandler : public MatrixHandler
+{
+public :
+    DelegateMatrixHandler(const AbstractMatrix& matrix) : MatrixHandler(matrix) {}
+
+    
+    
+    double interpolate(double  row, double  column) const { matrix_.interpolate(row, column); }
+    double nearest(double  row, double  column) const { matrix_.nearest(row, column); }
+
+    double column(int i, int j) const { matrix_.column(i, j); }
+    double row(int i, int j) const { matrix_.row(i, j); }
+
+protected :
 
 
 
+};
+
+
+#include <proj_api.h>
+
+class Proj4MatrixHandler : public MatrixHandler
+{
+public :
+    Proj4MatrixHandler(const AbstractMatrix& matrix, const string&);
+
+    
+    
+    double interpolate(double  row, double  column) const;
+    double nearest(double  row, double  column) const;
+
+    double column(int, int) const;
+    double row(int, int) const;
+
+    bool delegate() const { return true; }
+
+   
+
+protected :
+
+   double minx_;
+   double maxx_;
+   double miny_;
+   double maxy_;
+   
+   projPJ proj4_;
+   projPJ latlon_;
+
+};
+
+class RotatedMatrixHandler : public MatrixHandler
+{
+public :
+    RotatedMatrixHandler(const AbstractMatrix& matrix, double lat, double lon);
+
+    
+    
+    double interpolate(double  row, double  column) const;
+    double nearest(double  row, double  column) const;
+
+
+    double column(int, int) const;
+    double row(int, int) const;
+
+    bool delegate() const { return true; }
+    pair<double, double> unrotate(double, double) const;
+    pair<double, double> rotate(double, double) const;
+   
+
+protected :
+    
+   double minx_;
+   double maxx_;
+   double miny_;
+   double maxy_;
+   double southPoleLat_;
+   double southPoleLon_;
+
+};
+
 class BoxMatrixHandler : public TransformMatrixHandler
 {
 public:
@@ -609,6 +689,7 @@ protected :
 };
 
 
+
 class GeoBoxMatrixHandler: public TransformMatrixHandler
 {
 public:
