@@ -199,12 +199,16 @@ public:
 	void conic();
 	void geos();
 	void simple();
+	void projectionSimple();
+	
 	void add(double, double);
+
 	double patchDistance(double) const;
 	const string& name() const { return definition_; }
 	void getNewDefinition(const UserPoint&, const UserPoint&, string&) const;
 	void setDefinition(const string&);
 	void reprojectComponents(double&, double&, pair<double, double>&) const;
+	void reprojectSpeedDirection(const PaperPoint& point, pair<double, double>&) const;
 	virtual void geoProjection(int& geo) const { geo = 1; } // Useful for Streamlines !
 protected:
      //! Method to print string about this class on to a stream of type ostream (virtual).
@@ -259,6 +263,11 @@ class Proj4EPSG3857 : public Proj4Projection
 public:
 	Proj4EPSG3857() : Proj4Projection("EPSG:3857") {}
 };
+class Proj4EPSG900913 : public Proj4Projection
+{
+public:
+	Proj4EPSG900913() : Proj4Projection("EPSG:3857") {}
+};
 class Proj4Geos : public Proj4Projection
 {
 public:
