@@ -106,7 +106,7 @@ void SymbolAdvancedTableMode::adjust(double min, double max)
 	}
 	colourMethod_->set(*this);
 	height_method_->set(*this);
-	colourMethod_->prepare(*levels_);
+	colourMethod_->prepare(*levels_, *levels_);
 	height_method_->prepare(*levels_);
 	
 	if ( markers_.empty() ) {
@@ -191,8 +191,8 @@ void SymbolAdvancedTableMode::adjust(double min, double max)
     }
     // Here we add a last interval to close to the right the lst Interval.
 
-    MagLog::debug() << "[" << *level << ", " << (*level)+epsilon << "]=" <<colourMethod_->right(*level) << *marker << "(marker)" << *text << "(text)"<< endl;
-    map_[Interval(*level, (*level)+epsilon) ] = last;
+    MagLog::debug() << "[" << *level << ", " << (*level)+EPSILON << "]=" <<colourMethod_->right(*level) << *marker << "(marker)" << *text << "(text)"<< endl;
+    map_[Interval(*level, (*level)+EPSILON) ] = last;
 
 }
 
